Summary:        Sendmail milter for DomainKeys
Name:           dk-milter
Version:        0.5.0
Release:        0%{?dist}
License:        GPL
Group:          System Environment/Daemons
URL:            http://sourceforge.net/projects/dk-milter/

Source0:        http://prdownloads.sourceforge.net/dk-milter/%{name}-%{version}.tar.gz
Patch01:        dk-milter-0.4.1-postfix.patch
Patch02:        dk-milter-0.4.1-amd64.patch
Patch03:        dk-milter-0.4.1-ar.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  sendmail-devel, openssl
Requires:       sendmail

Requires(pre):  /usr/sbin/useradd
Requires(post): /sbin/chkconfig
Requires(post): /sbin/service
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service
Requires(postun): /sbin/service

%description
The dk-milter package is an open source implementation of the DomainKeys
sender authentication system proposed by Yahoo!, Inc.  It consists of a
library that implements the DomainKeys service, and a milter-based filter
application that can plug in to the sendmail MTA to provide that service
to sufficiently recent sendmail MTAs.

%prep
%setup -q
%patch01 -p1 -b .postfix
#%patch02 -p1 -b .amd64
%patch03 -p1 -b .ar

%{__cat} <<'EOF' >dk-milter.sysconfig
# Default values
#
#USER="dk-milt"
#PORT="inet:10035@localhost"
#SIGNING_DOMAIN="example.com"
#SELECTOR_NAME="dkimtest"
#KEYFILE="%{_sysconfdir}/mail/domainkeys/dk_${SELECTOR_NAME}.pem"
#SIGNER=yes
#VERIFIER=yes
#CANON=simple
#REJECTION="bad=r,dns=t,int=t,no=a,miss=r"
#EXTRA_ARGS="-h -l -D"

# User configuration
#
#PORT0="inet:10034@localhost"
#SIGNER0=no
#PORT1="inet:10035@localhost"
#VERIFIER1=no
#...
EOF

%{__cat} <<'EOF' >dk-milter.sysv
#!/bin/bash
#
# Init file for DomainKeys sendmail milter.
#
# chkconfig: - 79 21
# description: dk-filter is a daemon that hooks into sendmail and \
#              sign/verify mail according DomainKeys standard
#
# processname: dk-filter
# config: %{_sysconfdir}/sysconfig/dk-milter
# pidfile: %{_localstatedir}/run/dk-milter.pid

source %{_initrddir}/functions
source %{_sysconfdir}/sysconfig/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

[ -x %{_sbindir}/dk-filter ] || exit 1

### Default variables
USER="dk-milt"
PORT="inet:10035@localhost"
SIGNING_DOMAIN="example.com"
SELECTOR_NAME="dkimtest"
KEYFILE="%{_sysconfdir}/mail/domainkeys/dkim_${SELECTOR_NAME}.pem"
SIGNER=yes
VERIFIER=yes
CANON=simple
REJECTION="bad=r,dns=t,int=t,no=a,miss=r"
EXTRA_ARGS="-h -l -D"
SYSCONFIG="%{_sysconfdir}/sysconfig/dk-milter"

### Read configuration
[ -r "$SYSCONFIG" ] && source "$SYSCONFIG"
NUM=0
CMD_ARGS=()
while [ ! -z $(eval "echo \$PORT${NUM}") ]; do
  LPORT=${PORT}
  LSIGNING_DOMAIN=${SIGNING_DOMAIN}
  LSELECTOR_NAME=${SELECTOR_NAME}
  LKEYFILE=${KEYFILE}
  LSIGNER=${SIGNER}
  LVERIFIER=${VERIFIER}
  LCANON=${CANON}
  LREJECTION=${REJECTION}
  LEXTRA_ARGS=${EXTRA_ARGS}
  [ ! -z $(eval "echo \$PORT${NUM}") ] && LPORT=$(eval "echo \$PORT${NUM}")
  [ ! -z $(eval "echo \$SIGNING_DOMAIN${NUM}") ] && LSIGNING_DOMAIN=$(eval "echo \$SIGNING_DOMAIN${NUM}")
  [ ! -z $(eval "echo \$SELECTOR_NAME${NUM}") ] && LSELECTOR_NAME=$(eval "echo \$SELECTOR_NAME${NUM}")
  [ ! -z $(eval "echo \$KEYFILE${NUM}") ] && LKEYFILE=$(eval "echo \$KEYFILE${NUM}")
  [ ! -z $(eval "echo \$SIGNER${NUM}") ] && LSIGNER=$(eval "echo \$SIGNER${NUM}")
  [ ! -z $(eval "echo \$VERIFIER${NUM}") ] && LVERIFIER=$(eval "echo \$VERIFIER${NUM}")
  [ ! -z $(eval "echo \$CANON${NUM}") ] && LCANON=$(eval "echo \$CANON${NUM}")
  [ ! -z $(eval "echo \$REJECTION${NUM}") ] && LREJECTION=$(eval "echo \$REJECTION${NUM}")
  [ ! -z $(eval "echo \$EXTRA_ARGS${NUM}") ] && LEXTRA_ARGS=$(eval "echo \$EXTRA_ARGS${NUM}")
  LMODES=
  if [ x${LSIGNER:0:1} == "xy" -o x${LSIGNER:0:1} == "xY" ]; then
    LMODES=${LMODES}s
  fi
  if [ x${LVERIFIER:0:1} == "xy" -o x${LVERIFIER:0:1} == "xY" ]; then
    LMODES=${LMODES}v
  fi
  [ ! -z "$LMODES" ] && LMODES="-b $LMODES"
  CMD_ARGS[${NUM}]="-u $USER -p $LPORT -d $LSIGNING_DOMAIN -s $LKEYFILE -S $LSELECTOR_NAME $LMODES -c $LCANON -C $LREJECTION $LEXTRA_ARGS"
  NUM=$((${NUM}+1))
done
if [ ${#CMD_ARGS[*]} -eq 0 ]; then
  MODES=
  if [ x${SIGNER:0:1} == "xy" -o x${SIGNER:0:1} == "xY" ]; then
    MODES=${MODES}s
  fi
  if [ x${VERIFIER:0:1} == "xy" -o x${VERIFIER:0:1} == "xY" ]; then
    MODES=${MODES}v
  fi
  [ ! -z "$MODES" ] && MODES="-b $MODES"
  CMD_ARGS[0]="-u $USER -p $PORT -d $SIGNING_DOMAIN -s $KEYFILE -S $SELECTOR_NAME $MODES -c $CANON -C $REJECTION $EXTRA_ARGS"
fi

RETVAL=0
prog="dk-filter"
desc="DomainKeys milter"
#pidfile=%{_localstatedir}/run/dk-milter.pid

start() {
        for ((i=0; $i<${#CMD_ARGS[*]}; i=$(($i+1)) )); do
		pidfile=%{_localstatedir}/run/${prog}${i}.pid
		echo -n $"Starting $desc ($prog #$i): "
		touch $pidfile
		chown $USER $pidfile
		daemon --user $USER %{_sbindir}/${prog} ${CMD_ARGS[$i]} -P $pidfile
		RETVAL=$?
		echo
		[ $RETVAL -eq 0 ] && touch %{_localstatedir}/lock/subsys/${prog}${i}
        done
	return $RETVAL
}

stop() {
	echo -n $"Shutting down all $desc ($prog): "
	killproc $prog
	RETVAL=$?
	echo
	if [ $RETVAL -eq 0 ]; then
		for ((i=0; $i<${#CMD_ARGS[*]}; i=$(($i+1)) )); do
			pidfile=%{_localstatedir}/run/${prog}${i}.pid
			echo -n $"Cleanup for $desc ($prog #$i): "
			rm -f %{_localstatedir}/lock/subsys/${prog}${i}
			echo
		done
        fi
	return $RETVAL
}

restart() {
	stop
	sleep 2
	start
}

case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart|reload)
	restart
	;;
  condrestart)
	[ -e %{_localstatedir}/lock/subsys/${prog} ] && restart
	RETVAL=$?
	;;
  status)
	status $prog
	RETVAL=$?
	;;
  *)
	echo $"Usage: $0 {start|stop|restart|condrestart|status}"
	RETVAL=1
esac

exit $RETVAL
EOF

%build
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}

%{__install} -D -m0755 dk-milter.sysv %{buildroot}%{_initrddir}/dk-milter
%{__install} -D -m0644 dk-milter.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/dk-milter
%{__install} -d -m0700 %{buildroot}%{_localstatedir}/run/dk-milter
%{__install} -D -m0664 dk-filter/dk-filter.8 %{buildroot}%{_mandir}/man8/dk-filter.8
%{__install} -D -m0755 obj.`uname -s`.`uname -r`.`uname -p`/dk-filter/dk-filter %{buildroot}%{_sbindir}/dk-filter
%{__strip} %{buildroot}%{_sbindir}/dk-filter
%{__cp} dk-filter/README dk-filter/DK_README

%pre
/usr/sbin/useradd -r -s /sbin/nologin -d %{_localstatedir}/run/dk-milter \
	-c "DomainKeys Milter" dk-milt &>/dev/null || :

%post
/sbin/chkconfig --add dk-milter || :

%preun
if [ $1 -eq 0 ]; then
    /sbin/service dk-milter stop &>/dev/null || :
    /sbin/chkconfig --del dk-milter || :
fi

%postun
/sbin/service dk-milter condrestart &>/dev/null || :

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc FEATURES INSTALL KNOWNBUGS LICENSE README RELEASE_NOTES dk-filter/DK_README dk-filter/autorespond.csh dk-filter/gentxt.csh
%{_mandir}/man8/dk-filter.8*
%config(noreplace) %{_sysconfdir}/sysconfig/dk-milter
%{_initrddir}/dk-milter
%{_sbindir}/dk-filter
%dir %attr(-,dk-milt,root) %{_localstatedir}/run/dk-milter

%changelog
* Fri Jul  8 2006 Petr Vokac <vokac@kmlinux.fjfi.cvut.cz> - 0.4.1-1
- Initial package.
